<?php
/**
 * Created by: Andrey Polyakov (andrey@polyakov.im)
 */

namespace Travelpayouts\admin\redux;

use DI\DependencyException;
use DI\NotFoundException;
use Redux;
use Travelpayouts;
use Travelpayouts\components\Component;
use Travelpayouts\components\LanguageHelper;
use Travelpayouts\components\module\ModuleRedux;
use Travelpayouts\components\traits\SingletonTrait;

class OptionsInit extends Component
{
    use SingletonTrait;

    public $optName = TRAVELPAYOUTS_REDUX_OPTION;

    public function __construct()
    {
        if (class_exists('Redux')) {
            $this->register_redux_extensions();
            $this->attach_hooks();
            $this->render_modules_form();
        }
    }

    public function register_redux_extensions()
    {
        Redux::setExtensions($this->optName, Travelpayouts::getAlias('@admin/redux/extensions/'));
    }

    public function attach_hooks()
    {
        $optName = $this->optName;
        add_action("redux/page/$optName/form/before", [
            $this,
            'before_render',
        ], 10, 1);
    }

    public function before_render()
    {
        echo $this->renderFeedbackForm();
    }

    /**
     * Получаем список модулей, которые используют redux формы
     * @return array
     */
    protected function get_redux_modules()
    {
        try {
            if (($config = Travelpayouts::container()->get('config')) && isset($config['modules'])) {
                return array_filter($config['modules'], function ($module) {
                    $class = isset($module['class'])
                        ? $module['class']
                        : null;
                    return is_subclass_of($class, ModuleRedux::class);
                });
            }
        } catch (DependencyException $e) {
        } catch (NotFoundException $e) {
        }
        return [];
    }

    /**
     * Инициализируем формы из модулей
     */
    protected function render_modules_form()
    {
        $container = Travelpayouts::container();
        $modules = array_keys($this->get_redux_modules());
        array_walk($modules, static function ($moduleName) use ($container) {
            /**
             * @var ModuleRedux $module
             */
            $module = $container->get($moduleName);
            $module->registerSection();
        });
    }

    protected function renderFeedbackForm()
    {
        $templates = Travelpayouts::template();
        $locale = LanguageHelper::userLocale(false);

        $isRuLocale = $locale === 'ru_RU';
        $currentUser = wp_get_current_user();

        return $templates->render('admin::feedbackButton', [
            'buttonTitle' => $isRuLocale
                ? 'Сообщить о баге / оставить отзыв'
                : 'Report a bug / leave your feedback',
            'formId' => $isRuLocale
                ? 'HiJ9Gz8U'
                : 'pKhiBqhm',
            'buttonParams' => [
                'wp_version' => get_bloginfo('version'),
                'php_version' => PHP_VERSION,
                'plugin_version' => defined('TRAVELPAYOUTS_VERSION')
                    ? TRAVELPAYOUTS_VERSION
                    : '-',
                'domain' => home_url(),
                'plugin_locale' => $locale,
                'marker' => Travelpayouts::getInstance()->account->marker,
                'email' => $currentUser->user_email,
            ],
        ]);
    }
}
