<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

use Travelpayouts\admin\redux\base\ExtensionField;
use Travelpayouts\components\HtmlHelper;
use Travelpayouts\components\LanguageHelper;

if (!class_exists('ReduxFramework_Travelpayouts_Search_Forms')) {

    class ReduxFramework_Travelpayouts_Search_Forms extends ExtensionField
    {
        /**
         * Field Render Function.
         * Takes the vars and outputs the HTML for the field in the settings
         * @return      void
         * @since       1.0.0
         * @access      public
         */
        public function render()
        {
            echo HtmlHelper::tag('script', [], $this->add_translations());
            echo HtmlHelper::reactWidget('TravelpayoutsSearchForms', [
                'adminUrl' => admin_url('admin-ajax.php'),
                'data-r-prop-translation-messages' => 'TRAVELPAYOUTS_WP_PLUGIN',
            ]);
        }

        /**
         * Enqueue Function.
         * If this field requires any scripts, or css define this function and register/enqueue the scripts/css
         * @return      void
         * @since       1.0.0
         * @access      public
         */
        public function enqueue()
        {

            $this->add_translations();
        }

        protected function add_translations()
        {
            $messages = [
                'item_add_title' => Travelpayouts::__('Add a new search form'),
                'item_edit_title' => Travelpayouts::__('Edit the search form "{searchForm_name}"'),
                'item_title' => Travelpayouts::__('Title'),
                'item_from_city' => Travelpayouts::__('Default departure city'),
                'item_to_city' => Travelpayouts::__('Default arrival city'),
                'item_city_hotel' => Travelpayouts::__('Default city or hotel'),
                'item_widget_code' => Travelpayouts::__('Generated widget code'),
                'button_add' => Travelpayouts::__('Add'),
                'button_edit' => Travelpayouts::__('Edit'),
                'button_cancel' => Travelpayouts::__('Cancel'),
                'button_ok' => Travelpayouts::__('Ok'),
                'button_delete' => Travelpayouts::__('Delete'),
                'button_add_new_item' => Travelpayouts::__('Add a new search form'),
                'grid_column_title' => Travelpayouts::__('Title'),
                'grid_column_date' => Travelpayouts::__('Date'),
                'grid_column_shortcode' => Travelpayouts::__('Shortcode'),
                'grid_column_actions' => Travelpayouts::__('Actions'),
                'grid_button_remove_items' => Travelpayouts::_x('Remove {num, plural, one {# item} other {# items}}', '{num, plural, one {# VALUE_NAME} other {# VALUE_NAMES}}'),
                'autocomplete_not_found' => Travelpayouts::__('Not found.'),
                'item_create_success' => Travelpayouts::__('item has been created'),
                'item_remove_success' => Travelpayouts::__('item has been removed'),
                'item_remove_title' => Travelpayouts::__('Do you want to delete this item?'),
                'item_remove_description' => Travelpayouts::__('This item will be deleted permanently. This operation cannot be undone.'),
                'item_update_success' => Travelpayouts::__('item has been updated'),
                'items_remove_success' => Travelpayouts::__('selected items have been successfully removed'),
                'item_create_error' => Travelpayouts::__('An error has occurred while creating the search form'),
                'item_remove_error' => Travelpayouts::__('An error has occurred while removing the search form'),
                'items_remove_error' => Travelpayouts::__('An error has occurred while removing search forms'),
            ];

            $validatorRules = [
                'mixed' => [
                    'default' => Travelpayouts::_x('${path} is invalid.', 'frontend validator rules'),
                    'required' => Travelpayouts::_x('${path} is a required field.', 'frontend validator rules'),
                    'oneOf' => Travelpayouts::_x('${path} must be one of the following values: ${values}', 'frontend validator rules'),
                    'notOneOf' => Travelpayouts::_x('${path} must not be one of the following values: ${values}', 'frontend validator rules'),
                    'notType' => Travelpayouts::_x('${path} has incorrect value', 'frontend validator rules')
                ],
                'string' => [
                    'length' => Travelpayouts::_x('${path} must be exactly ${length} characters', 'frontend validator rules'),
                    'min' => Travelpayouts::_x('${path} must be at least ${min} characters', 'frontend validator rules'),
                    'max' => Travelpayouts::_x('${path} must be at most ${max} characters', 'frontend validator rules'),
                    'matches' => Travelpayouts::_x('${path} must match the following: "${regex}"', 'frontend validator rules'),
                    'email' => Travelpayouts::_x('${path} must be a valid email', 'frontend validator rules'),
                    'url' => Travelpayouts::_x('${path} must be a valid URL', 'frontend validator rules'),
                    'trim' => Travelpayouts::_x('${path} must be a trimmed string', 'frontend validator rules'),
                    'lowercase' => Travelpayouts::_x('${path} must be a lowercase string', 'frontend validator rules'),
                    'uppercase' => Travelpayouts::_x('${path} must be a upper case string', 'frontend validator rules'),
                ],
                'number' => [
                    'min' => Travelpayouts::_x('${path} must be greater than or equal to ${min}', 'frontend validator rules'),
                    'max' => Travelpayouts::_x('${path} must be less than or equal to ${max}', 'frontend validator rules'),
                    'lessThan' => Travelpayouts::_x('${path} must be less than ${less}', 'frontend validator rules'),
                    'moreThan' => Travelpayouts::_x('${path} must be greater than ${more}', 'frontend validator rules'),
                    'notEqual' => Travelpayouts::_x('${path} must be not equal to ${notEqual}', 'frontend validator rules'),
                    'positive' => Travelpayouts::_x('${path} must be a positive number', 'frontend validator rules'),
                    'negative' => Travelpayouts::_x('${path} must be a negative number', 'frontend validator rules'),
                    'integer' => Travelpayouts::_x('${path} must be an integer', 'frontend validator rules'),
                ],
                'object' => [
                    'noUnknown' => Travelpayouts::_x('${path} field cannot have keys not specified in the object shape', 'frontend validator rules'),
                ],
                'array' => [
                    'min' => Travelpayouts::_x('${path} field must have at least ${min} items', 'frontend validator rules'),
                    'max' => Travelpayouts::_x('${path} field must have less than or equal to ${max} items', 'frontend validator rules'),
                ]
            ];

            $messagesString = json_encode($messages);
            $validatorRulesString = json_encode($validatorRules);
            $locale = LanguageHelper::fallbackLocaleDashboard();
            $scriptContent = <<<JS
window.TRAVELPAYOUTS_WP_PLUGIN = window.TRAVELPAYOUTS_WP_PLUGIN || {};
window.TRAVELPAYOUTS_WP_PLUGIN.validatorRules = {$validatorRulesString};
window.TRAVELPAYOUTS_WP_PLUGIN.locale = "{$locale}";
window.TRAVELPAYOUTS_WP_PLUGIN.searchForms = {$messagesString};
JS;
            return $scriptContent;
        }
    }
}
