(function ($) {
    "use strict";

    if (typeof travelpayouts_search_forms == "undefined") {
        return;
    }

    var airport_source = "//autocomplete.travelpayouts.com/places2?locale=" +
        travelpayouts_search_forms.airport.locale +
        "&types[]=city,airport";

    var hotel_source = "//yasen.hotellook.com/autocomplete?lang=" +
        travelpayouts_search_forms.hotel.locale +
        "&term=";

    $.fn.travelpayoutsAcHotel = function (source) {
        var hotel_cache = {};

        this.autocomplete({
            minLength: 2,
            source: function (request, response) {
                var term = encodeURIComponent(request.term);
                if (term in hotel_cache) {
                    response(hotel_cache[term]);
                    return;
                }

                $.getJSON(
                    source + term,
                    request, function (data, status, xhr) {

                        var hotels = [];
                        $.each(data.cities, function (key, value) {
                            hotels.push({
                                label: value.fullname + ' [' + value.hotelsCount + ']',
                                value: value
                            });
                        });
                        $.each(data.hotels, function (key, value) {
                            hotels.push({
                                label: value.hotelFullName,
                                value: value
                            });
                        });

                        hotel_cache[term] = hotels;

                        response(hotels);

                    }
                ).fail(function () {
                    response();
                });
            },
            select: function( event, ui ) {
                $(this).val(ui.item.label);
                $(this).parent().find('input[type="hidden"].select-raw').val(JSON.stringify(ui.item.value));
                return false;
            }
        });
        this.on('blur', function () {
            if ($(this).hasClass('ui-autocomplete-input')) {
                $(this).autocomplete('destroy');
            }
        });
        return this;
    };

    $.fn.travelpayoutsAcAirport = function (source) {
        var airport_cache = {};

        this.autocomplete({
            minLength: 2,
            source: function (request, response) {
                var term = encodeURIComponent(request.term);
                if (term in airport_cache) {
                    response(airport_cache[term]);
                    return;
                }

                $.getJSON(
                    source,
                    request, function (data, status, xhr) {
                        var airports = [];
                        $.each(data, function (key, value) {
                            airports.push({
                                label: value.name + ', ' + value.country_name + ' [' + value.code + ']',
                                value: value
                            });
                        });

                        airport_cache[term] = airports;

                        response(airports);

                    }
                ).fail(function () {
                    response();
                });
            },
            select: function( event, ui ) {
                $(this).val(ui.item.label);
                $(this).parent().find('input[type="hidden"].select-raw').val(JSON.stringify(ui.item.value));
                return false;
            }
        });

        this.on('blur', function () {
            if ($(this).hasClass('ui-autocomplete-input')) {
                $(this).autocomplete('destroy');
            }
        });
        return this;
    };

    $.fn.toRaw = function () {
        var value = $(this).val(),
            raw = {
                'id': '',
                'label': ''
            };
        value = value.replace(']', '');
        var list = value.split(' [');

        return raw;
    };

    var airport_input = 'input.travelpayouts-search-forms-airport',
        hotel_input = 'input.travelpayouts-search-forms-hotel';


    $(document).on('focus', airport_input, function () {
        $(this).travelpayoutsAcAirport(airport_source);
    });

    $(document).on('focus', hotel_input, function () {
        $(this).travelpayoutsAcHotel(hotel_source);
    });

})(jQuery);