<?php
/**
 * Created by: Andrey Polyakov (andrey@polyakov.im)
 */

namespace Travelpayouts\components;

use Exception;
use Travelpayouts\components\traits\SingletonTrait;

abstract class Controller extends BaseInjectedObject
{
    use SingletonTrait;

    public function get_input_data()
    {
        try {
            /*
             * php://input reads raw data from the request body, can lead to RCE if used in eval
             * Думаю можно оставить, так как это под защитой админки и тд
             */
            $jsonData = file_get_contents('php://input');
            return json_decode($jsonData, true);
        } catch (Exception $e) {
            return null;
        }
    }

    public function get_input($name = null)
    {
        $inputData = $this->get_input_data();
        if ($inputData) {
            if ($name) {
                return isset($inputData[$name])
                    ? $inputData[$name]
                    : null;
            }
            return $inputData;
        }
        return null;
    }

    /***
     * @param bool $success
     * @param array $content
     * @param bool $return
     * @return false|string|void
     */
    public function response($success, $content = [], $return = false)
    {
        $output = array_merge($content, [
            'status' => $success
                ? 'ok'
                : 'error',
            'success' => $success,
        ]);
        return $return
            ? wp_json_encode($output)
            : wp_send_json($output);
    }
}
