<?php

namespace Travelpayouts\components;

use Travelpayouts;
use Travelpayouts\components\Translator;

class LanguageHelper
{
    const DASHBOARD_RUSSIAN = 'ru';
    const DASHBOARD_ENGLISH = 'en';
    const DASHBOARD_UKRAINIAN = 'uk';
    const DASHBOARD_BELORUSSIAN = 'be';
    const DASHBOARD_BULGARIAN = 'bg';
    const TABLE_DEFAULT = 'en';

    protected static $fallbackLocales = [
        self::DASHBOARD_BELORUSSIAN => self::DASHBOARD_RUSSIAN,
        self::DASHBOARD_UKRAINIAN => self::DASHBOARD_RUSSIAN,
    ];

    /**
     * true если язык ru другие false
     *
     * @return bool
     */
    public static function isRuDashboard()
    {
        return self::dashboardLocale() === self::DASHBOARD_RUSSIAN;
    }

    /**
     * TODO пока что не используется, возможно для фидбек формы и в других местах стоит использовать
     *
     * @return bool
     */
    public static function isRuFallbackDashboard()
    {
        return self::fallbackLocaleDashboard() === self::DASHBOARD_RUSSIAN;
    }

    /**
     * @param $lang
     * @return bool
     */
    public static function useCaseInTables($lang)
    {
        switch ($lang) {
            case Translator::RUSSIAN:
            case Translator::BELARUSIAN:
            case Translator::TAJIK:
            case Translator::CHECHEN:
            case Translator::KAZAKH:
            case Translator::UZBEK:
            case Translator::UKRAINIAN:
                return true;
            default:
                return false;
        }
    }

    /**
     * @return string
     */
    public static function fallbackLocaleDashboard()
    {
        $locale = self::dashboardLocale();
        switch ($locale) {
            case self::DASHBOARD_RUSSIAN:
            case self::DASHBOARD_BELORUSSIAN:
            case self::DASHBOARD_BULGARIAN:
            case self::DASHBOARD_UKRAINIAN:
                return self::DASHBOARD_RUSSIAN;
            default:
                return self::DASHBOARD_ENGLISH;
        }
    }

    /**
     * Если язык админки ru врнет ru все остальные en
     *
     * @return string
     */
    public static function binaryLocaleDashboard()
    {
        return self::isRuDashboard() ? self::DASHBOARD_RUSSIAN : self::DASHBOARD_ENGLISH;
    }

    /**
     * Возвращает язык адмики wp который выбран в настройках wp
     *
     * @param bool $short
     * @return false|string|void
     */
    public static function dashboardLocale($short = true)
    {
        $locale = get_bloginfo('language');

        if (!$short) {
            return $locale;
        }

        return self::shortLocale($locale);
    }

    /**
     * Возвращает язык пользователя из настроек wp
     *
     * @param bool $short
     * @return false|string
     */
    public static function userLocale($short = true)
    {
        $locale = get_user_locale();

        if (!$short) {
            return $locale;
        }

        return self::shortLocale($locale);
    }

    /**
     * @param null $directLocale
     * @return string
     */
    public static function tableLocale($directLocale = null)
    {
        if (!empty($directLocale)) {
            return $directLocale;
        }

        return Travelpayouts::getInstance()->settings
            ? Travelpayouts::getInstance()->settings->getLanguage()
            : Translator::ENGLISH;
    }

    /**
     * Получаем локаль из translator компонента
     * @param bool $fallbackLocale - возвращает оригинальный код локали или код фоллбек языка
     * @return mixed|string
     */
    public static function tableTranslatorLocale($fallbackLocale = true)
    {
        return Travelpayouts::getInstance()->translator
            ? Travelpayouts::getInstance()->translator->getLocale($fallbackLocale)
            : Translator::ENGLISH;
    }

    protected static function shortLocale($locale)
    {
        return substr($locale, 0, 2);
    }

    /**
     * Возвращает id поля для текущего языка {field_id} + _{currentLang}
     * ничего не делает если текущий язык это дефолтный язык плагина мультиязычности
     *
     * @param $option
     * @param null $tableLocale
     * @return string
     */
    public static function optionWithLanguage($option, $tableLocale = null)
    {
        $langData = Travelpayouts::multiLang()->data;

        $current = $langData['current'];
        if (!empty($tableLocale)) {
            $current = $tableLocale;
        }

        if (empty($langData) || empty($current) || $current === $langData['default']) {
            return $option;
        }

        return $option . '_' . $current;
    }

    public static function optionData($data, $optionName, $locale)
    {
        $option = LanguageHelper::optionWithLanguage($optionName, $locale);
        $default = $data->get($optionName);

        return $data->get($option, $default);
    }
}
