<?php

namespace Travelpayouts\components;

use Travelpayouts;

/**
 * Class Notices
 * @package Travelpayouts\src\components
 */
class Notices
{
    const NOTICE_SUCCESS = 'success';
    const NOTICE_ERROR = 'error';
    const NOTICE_WARNING = 'warning';
    const NOTICE_INFO = 'info';
    const NOTICE_DISMISSIBLE = 'is-dismissible';

    const IS_ACTIVE_REDUX = 'is-active-redux-notice';
    const REDUX_IMPORT_NOTICE = 'redux-import-notice';
    const REDUX_IMPORT_ACTION_NOTICE = 'redux-import-action-notice';

    /**
     * @return mixed|void
     */
    protected static function getNotices()
    {
        return get_option(self::getOptName(), []);
    }

    /**
     * Отображает уведомления и очищает их сразу после отображения
     */
    public static function render()
    {
        $notices = Notices::getNotices();
        foreach ($notices as $key => $notice) {
            echo $notice;
        }

        if (!empty($notices)) {
            Notices::clearNotices();
        }
    }

    /**
     * @param $key
     * @param $value
     * @return bool
     */
    public static function addNotice($key, $value)
    {
        $notices = self::getNotices();
        $notices[$key] = $value;

        return self::updateOption($notices);
    }

    /**
     * @param $key
     * @return bool
     */
    public static function clearNotice($key)
    {
        $notices = self::getNotices();
        unset($notices[$key]);

        return self::updateOption($notices);
    }

    /**
     * @return bool
     */
    protected static function clearNotices()
    {
        return self::updateOption([]);
    }

    /**
     * @param $data
     * @return bool
     */
    private static function updateOption($data)
    {
        return update_option(self::getOptName(), $data);
    }

    /**
     * @return string
     */
    private static function getOptName()
    {
        return TRAVELPAYOUTS_PLUGIN_NAME . '_notices';
    }

    /**
     * @param $message
     * @param $type
     * @param bool $dismissible
     * @return string
     */
    private static function getHtmlNotice($message, $type, $dismissible = true)
    {
        $class_dismissible = '';
        if ($dismissible) {
            $class_dismissible = ' is-dismissible';
        }

        return HtmlHelper::tag(
            'div',
            [
                'class' => 'notice notice-' . $type . $class_dismissible
            ],
            HtmlHelper::tag('p', [], $message)
        );
    }

    /**
     * @param $key
     * @param $message
     * @return bool
     */
    public static function addSuccessNotice($key, $message)
    {
        return self::addNotice(
            $key,
            self::getHtmlNotice($message, self::NOTICE_SUCCESS)
        );
    }

    /**
     * @param $key
     * @param $message
     * @return bool
     */
    public static function addErrorNotice($key, $message)
    {
        return self::addNotice(
            $key,
            self::getHtmlNotice($message, self::NOTICE_ERROR)
        );
    }

    /**
     * @param $key
     * @param $message
     * @return bool
     */
    public static function addWarningNotice($key, $message)
    {
        return self::addNotice(
            $key,
            self::getHtmlNotice($message, self::NOTICE_WARNING)
        );
    }

    /**
     * @param $key
     * @param $message
     * @return bool
     */
    public static function addInfoNotice($key, $message)
    {
        return self::addNotice(
            $key,
            self::getHtmlNotice($message, self::NOTICE_INFO)
        );
    }

    /**
     * @param $type
     * @param $title
     * @param $description
     * @param $href
     * @param $link
     * @return bool
     */
    public static function addStyledNotice($type, $title, $description, $href, $link)
    {
        return Notices::addNotice(
            $type,
            Travelpayouts::template()->render('admin::notices/default', [
                'title' => $title,
                'description' => $description,
                'link' => $link,
                'href' => $href,
            ])
        );
    }

    public static function addStyledImportNotice($type, $title, $description, $link)
    {
        return Notices::addNotice(
            $type,
            Travelpayouts::template()->render('admin::notices/import', [
                'title' => $title,
                'description' => $description,
                'link' => $link,
            ])
        );
    }
}
