<?php
/**
 * Created by: Andrey Polyakov (andrey@polyakov.im)
 */

namespace Travelpayouts\components;

use Exception;
use Travelpayouts;
use Travelpayouts\components\httpClient\Client;
use Travelpayouts\components\traits\SingletonTrait;

/**
 * Class Subscriptions
 * @package Travelpayouts\components
 */
class Subscriptions extends BaseObject
{
    use SingletonTrait;

    const CACHE_TIME = 3600; // кешируем данные на час
    const CACHE_PREFIX = 'travelpayouts_subscriptions_ids_';
    const SUBSCRIPTIONS_CHECKER_ENDPOINT = 'https://www.travelpayouts.com/campaigns/get_campaigns_subscriptions';

    protected $_subscriptionsList;
    protected $_currentCacheKey;

    const TP_TUTU_ID = 45;
    const HOTELLOOK_ID = 101;
    const AVIASALES_ID = 100;

    protected function getSubscriptionsList()
    {
        $cacheKey = $this->getCacheKey();
        if (!$cacheKey) return [];

        if (!$this->_subscriptionsList && $this->_currentCacheKey !== $cacheKey) {
            $subscriptionsList = get_transient($cacheKey);
            if ($subscriptionsList === false) {
                $client = new Client(
                    [
                        'timeout' => 15,
                    ]
                );
                $response = $client->get(self::SUBSCRIPTIONS_CHECKER_ENDPOINT, [
                    'params' => [
                        'marker' => $this->getMarker(),
                    ],
                ]);
                $subscriptionsList = [];
                if (!$response->isError &&
                    $response->statusCode === 200 &&
                    $response->json &&
                    isset($response->json['subscriptions'])
                ) {
                    $subscriptionsList = $response->json['subscriptions'];
                }
                set_transient($cacheKey, $subscriptionsList, self::CACHE_TIME);
            }
            $this->_subscriptionsList = $subscriptionsList;
        }
        return $this->_subscriptionsList;
    }

    /**
     * Проверяем доступность сервиса
     * @param $id
     * @return bool
     */
    public function isActive($id)
    {
        if ((is_string($id) || is_int($id)) && preg_match('/^(\d*)$/', $id)) {
            $id = (int)$id;
            $subscriptionsList = $this->getSubscriptionsList();
            return in_array($id, $subscriptionsList, true);
        }
        return false;
    }

    /**
     * @return string|null
     */
    public function getCacheKey()
    {
        return $this->getMarker()
            ? self::CACHE_PREFIX . $this->getMarker()
            : null;
    }

    /**
     * Получаем маркер напрямую, минуя travelPayouts DI
     * @return string|null
     */
    protected function getMarker()
    {
        try {
            $redux = Travelpayouts::getRedux();
            $options = $redux->get_options();
            return isset($options['account_api_marker']) && !empty($options['account_api_marker'])
                ? $options['account_api_marker']
                : null;
        } catch (Exception $e) {
            return null;
        }
    }
}
