<?php

namespace Travelpayouts\components\snowplow;

use DI\Container;
use Exception;
use Snowplow\Tracker\Emitters\SyncEmitter;
use Snowplow\Tracker\Subject;
use Travelpayouts\components\BaseObject;

/**
 * Class TrackerHelper
 * @package Travelpayouts\components\snowplow
 */
class TrackerHelper
{
    const CATEGORY_INSTALL = 'install';
    // Событие отправляется при установки плагина
    const ACTION_INSTALLED = 'plugin_installed';
    // событие отправляетс после того как пользователь ввел свой маркер и сохранил настройки
    const ACTION_ACTIVATED = 'plugin_activated';
    // обновление версии плагина с предыдущей
    const ACTION_UPDATED = 'plugin_updated';

    public static function createTracker(Container $c)
    {
        $config = $c->get('config');

        if (isset($config['snowplow']['emitter'], $config['snowplow']['tracker'], $config['snowplow']['context'])) {
            $emitter = $config['snowplow']['emitter'];
            $tracker = $config['snowplow']['tracker'];
            if (isset($tracker['className']) &&
                is_subclass_of($tracker['className'], \Snowplow\Tracker\Tracker::class)) {
                $trackerClassName = $tracker['className'];
                $tracker = new $trackerClassName(
                    new SyncEmitter(
                        $emitter['url'],
                        $emitter['protocol'],
                        $emitter['post_type'],
                        $emitter['buffer_size'],
                        $emitter['debug']
                    ),
                    new Subject(),
                    $tracker['namespace'],
                    $tracker['app_id']
                );
                if (is_callable($config['snowplow']['context'])) {
                    $context = $config['snowplow']['context'];
                    $tracker->setContext($context());
                }
                return $tracker;
            }
        }

        throw new Exception('Can\'t find slowoplow config entry');
    }
}
