<?php
/**
 * Created by: Andrey Polyakov (andrey@polyakov.im)
 */

namespace Travelpayouts\components\traits;

use DI\Container;
use DI\ContainerBuilder;
use DI\DependencyException;
use DI\NotFoundException;
use function DI\object;

/**
 * Trait DITrait
 * @package Travelpayouts\components\traits
 * @property-read Container $container
 * @property-read array $components
 */
trait DITrait
{
    protected $_container;
    private $components = [];

    /**
     * @return Container
     */
    public function get_container()
    {
        return $this->_container;
    }

    public function get_components()
    {
        return $this->components;
    }

    public function add_components($componentsList)
    {
        foreach ($componentsList as $componentName => $componentParams) {
            if (is_int($componentName)) {
                $this->add_component($componentParams);
            } else {
                $this->add_component($componentName, $componentParams);
            }
        }
    }

    /**
     * @param $name
     * @param array|string $params
     */
    public function add_component($name, $params = [])
    {
        if (is_int($name)) {
            if (is_string($params)) {
                $class = $params;
                $depName = $params;
                $params = [];
            } elseif (is_array($params) && isset($params['class'])) {
                $class = $params['class'];
                unset($params['class']);
                $depName = $class;
            }
        } elseif (is_string($name)) {
            $depName = $name;
            if (is_string($params)) {
                $class = $params;
                $params = [];
            } elseif (is_array($params)) {
                if (isset($params['class'])) {
                    $class = $params['class'];
                    unset($params['class']);
                } else {
                    $class = $name;
                }

            }
        }

        if (isset($depName, $class) && !$this->get_container()->has($depName)) {
            $params['name'] = $depName;
            $this->get_container()->set($depName, object($class)->constructorParameter('config', $params));
            $this->components[$depName] = $class;
        }
    }


    /**
     * Получаем отдельный компонент по имени
     * @param $name
     * @return mixed|null
     * @throws DependencyException
     * @throws NotFoundException
     */
    public function get_component($name)
    {
        if ($this->has_component($name)) {
            return $this->get_container()->has($name)
                ? $this->get_container()->get($name)
                : null;
        }
        return null;
    }

    public function has_component($name)
    {
        return $this->_container->has($name);
    }

    public function createContainer($definitionsList = [])
    {
        if (!$this->_container) {
            $builder = new ContainerBuilder();
            $builder->useAutowiring(true);
            $builder->useAnnotations(true);

            foreach ($definitionsList as $definition) {
                $builder->addDefinitions($definition);
            }
            $this->_container = $builder->build();
        }
    }

    /**
     * @param string $name
     * @return mixed|null
     */
    public function __get($name)
    {
        return $this->has_component($name)
            ? $this->get_component($name)
            : parent::__get($name);
    }

    /**
     * @param string $name
     * @return bool
     */
    public function __isset($name)
    {
        return $this->has_component($name)
            ? true
            : parent::__isset($name);
    }

    public function __set($name, $value)
    {
        parent::__set($name, $value);
    }

}
