<?php

namespace Travelpayouts\components\validators;
use Travelpayouts;

/**
 * RequiredValidator validates that the specified attribute does not have null or empty value.
 * @author Qiang Xue <qiang.xue@gmail.com>
 * @since 2.0
 */
Class ValidatorRequired extends ValidatorRule
{
    /**
     * @var bool whether to skip this validator if the value being validated is empty.
     */
    public $skipOnEmpty = false;
    /**
     * @var mixed the desired value that the attribute must have.
     * If this is null, the validator will validate that the specified attribute is not empty.
     * If this is set as a value that is not null, the validator will validate that
     * the attribute has a value that is the same as this property value.
     * Defaults to null.
     * @see strict
     */
    public $requiredValue;
    /**
     * @var bool whether the comparison between the attribute value and [[requiredValue]] is strict.
     * When this is true, both the values and types must match.
     * Defaults to false, meaning only the values need to match.
     * Note that when [[requiredValue]] is null, if this property is true, the validator will check
     * if the attribute value is null; If this property is false, the validator will call [[isEmpty]]
     * to check if the attribute value is empty.
     */
    public $strict = false;
    /**
     * @var string the user-defined error message. It may contain the following placeholders which
     * will be replaced accordingly by the validator:
     * - `{attribute}`: the label of the attribute being validated
     * - `{value}`: the value of the attribute being validated
     * - `{requiredValue}`: the value of [[requiredValue]]
     */
    public $message;

    public function init()
    {
        if ($this->message === null) {
            $this->message = $this->requiredValue === null
                ? Travelpayouts::__('{attribute} cannot be blank.')
                : Travelpayouts::__('{attribute} must be "{requiredValue}".');
        }
    }


    protected function validate_value($value)
    {
        if ($this->requiredValue === null) {
            if ((($this->strict && $value !== null) || (!$this->strict && !$this->isEmpty(is_string($value))) ? trim($value) : $value)) {
                return null;
            }
        } elseif ((!$this->strict && $value == $this->requiredValue) || ($this->strict && $value === $this->requiredValue)) {
            return null;
        }
        if ($this->requiredValue === null) {
            return [$this->message, []];
        }

        return [$this->message, [
            'requiredValue' => $this->requiredValue,
        ]];
    }

}
