<?php
/**
 * Created by: Andrey Polyakov (andrey@polyakov.im)
 */

use DI\Container;
use League\Plates\Engine;
use Rollbar\Rollbar;
use Travelpayouts\admin\Admin;
use Travelpayouts\components\Assets;
use Travelpayouts\components\base\cache\CacheFromSettings;
use Travelpayouts\components\multilingual\MultiLang;
use Travelpayouts\components\rest\FrontRestRoutes;
use Travelpayouts\components\snowplow\TrackerHelper;
use Travelpayouts\frontend\Frontend;
use Travelpayouts\includes\ReduxConfigurator;
use Travelpayouts\includes\Router;
use function DI\object;

return [
    [
        'version' => TRAVELPAYOUTS_VERSION,
        'name' => 'travelpayouts',
    ],
    __DIR__ . '/redux.php',
    __DIR__ . '/config.php',
    [
        'rollbar' => static function (Container $c) {
            $config = $c->get('config');
            $rollbarConfig = isset($config['rollbar']) && is_callable($config['rollbar'])
                ? $config['rollbar']()
                : [];
            Rollbar::init($rollbarConfig, false, false, false);
            return Rollbar::logger();
        },
        'cache' => object(CacheFromSettings::getCacheClass()),
        'redux' => static function (Container $c) {
            $args = $c->get('redux_args');
            return new ReduxConfigurator($args['opt_name'], $args);
        },
        'rest' => object(FrontRestRoutes::class),
        'frontend' => object(Frontend::class),
        'admin' => object(Admin::class),
        'template' => static function () {
            $templateInstance = new Engine();
            $templateInstance->addFolder('admin', Travelpayouts::getAlias('@src/admin/templates'));
            return $templateInstance;
        },
        'snowTracker' => static function (Container $c) {
            return TrackerHelper::createTracker($c);
        },
        'multiLang' => static function () {
            return new MultiLang();
        },
        'router' => static function (Container $c) {
            $config = $c->get('config');
            $routerConfig = isset($config['router'])
                ? $config['router']
                : [];

            return new Router($routerConfig);
        },
        'assets' => object(Assets::class),
    ],
];
