<?php
/**
 * Created by: Andrey Polyakov (andrey@polyakov.im)
 */

namespace Travelpayouts\modules\searchForms;

use Adbar\Dot;
use DI\Annotation\Inject;
use Travelpayouts\components\module\ModuleRedux;
use Travelpayouts\includes\Router;
use Travelpayouts\modules\searchForms\components\ItemsController;

/**
 * Class Search
 * @package Travelpayouts\src\modules\searchForms
 * @property-read SearchForm $section
 * @property-read Dot $data
 */
class Search extends ModuleRedux
{
    /**
     * @Inject
     * @var SearchForm
     */
    public $section;

    /**
     * @Inject("router")
     * @var Router
     */
    protected $router;
    /**
     * @inheritdoc
     */
    protected $shortcodeList = [
        components\SearchShortcodes::class,
    ];

    public function init()
    {
        $this->setUpRoutes();
    }

    protected function setUpRoutes()
    {
        $controller = new ItemsController();
        $this->router->addRoutes([
            ['GET', 'searchForms', [$controller, 'action_index']],
            ['POST', 'searchForms', [$controller, 'action_create']],
            ['PUT', 'searchForms/deleteById', [$controller, 'action_delete_by_id']],
            ['GET', 'searchForms/{id:\d+}', [$controller, 'action_view']],
            ['GET', 'searchForms/slug/{slug:\w+}', [$controller, 'action_view_by_slug']],
            ['PUT', 'searchForms/{id:\d+}', [$controller, 'action_edit']],
            ['DELETE', 'searchForms/{id:\d+}', [$controller, 'action_delete']],
        ]);
    }

    /**
     * @inheritdoc
     */
    public function registerSection()
    {
        $this->section->register();
    }

    /**
     * @return Dot
     */
    public function getData()
    {
        return $this->section->data;
    }
}
