<?php
/**
 * Created by: Andrey Polyakov (andrey@polyakov.im)
 */

namespace Travelpayouts\modules\searchForms\components;

use Travelpayouts\components\Controller;
use Travelpayouts\modules\searchForms\components\models\SearchFormsModel;

/**
 * Class ItemsController
 * @package Travelpayouts\modules\searchForms\components
 * @property-read SearchFormsModel $model
 */
class ItemsController extends Controller
{
    public function action_index()
    {
        $this->response(true, [
            'items' => $this->model->data,
        ]);
    }

    public function action_view($id)
    {
        $item = $this->model->view($id);
        if ($item) {
            $this->response(true, [
                'item' => $item,
            ]);
        }
        $this->response(false);
    }

    public function action_view_by_slug($slug)
    {
        $item = $this->model->findByColumnValue('slug', $slug);

        if ($item) {
            $this->response(true, [
                'item' => $item,
            ]);
        }
        $this->response(false);
    }

    public function action_create()
    {
        $input = $this->get_input('item');

        return $this->response($this->model->create($input));
    }

    public function action_edit($id)
    {
        $input = $this->get_input('item');

        try {
            return $this->response($this->model->update($id, $input));
        } catch (\Exception $e) {
            return $this->response(false);
        }
    }

    public function action_delete($id)
    {
        try {
            $this->response($this->model->delete($id));
        } catch (\Exception $e) {
            return $this->response(false);
        }
    }

    public function action_delete_by_id()
    {
        $model = $this->model;
        $model->deleteMany(
            $this->get_input('items')
        );
        $this->response(true);
    }

    /**
     * @return SearchFormsModel
     */
    protected function getModel()
    {
        return new SearchFormsModel();
    }
}
