<?php

namespace Travelpayouts\modules\searchForms\components\models;

use Adbar\Dot;
use Travelpayouts\components\model\ReduxOptionCollectionModel;
use Travelpayouts\modules\searchForms\components\SearchShortcodes;

class SearchFormsModel extends ReduxOptionCollectionModel
{
    const DATE_FORMAT = 'Y-m-d';

    /**
     * Все поисковые формы в видео опций для селекта
     *
     * @return array
     */
    public function getFormsSelect()
    {
        return $this->selectData($this->getData());
    }

    /**
     * Делает из форм опции для селекта
     *
     * @param $forms
     * @return array
     */
    public function selectData($forms)
    {
        return array_reduce($forms, function ($accumulator, $currentValue) {
            return $accumulator + [$currentValue['id'] => $currentValue['title']];
        }, []);
    }

    /**
     * @return array
     */
    public function getFlightsForms()
    {
        return $this->filter('type_form', [
            SearchShortcodes::TYPE_AVIA,
            SearchShortcodes::TYPE_AVIA_HOTEL,
        ]);
    }

    /**
     * @return array
     */
    public function getHotelsForms()
    {
        return $this->filter('type_form', [
            SearchShortcodes::TYPE_HOTEL,
//            SearchShortcodes::TYPE_AVIA_HOTEL,
        ]);
    }

    /**
     * @param $attributes
     * @return bool
     */
    public function create($attributes)
    {
        return parent::create($this->prepareAttributes($attributes));
    }

    /**
     * @param $attributes
     * @return array
     */
    private function prepareAttributes($attributes)
    {
        $attributes = new Dot($attributes);

        // Из code_form получаем type_form
        $code = $attributes->get('code_form', '');

        return [
            'code_form' => $code,
            'title' => $attributes->get('title', ''),
            'from_city' => $attributes->get('from_city', ''),
            'to_city' => $attributes->get('to_city', ''),
            'hotel_city' => $attributes->get('hotel_city', ''),
            'date_add' => $attributes->get('date_add', date(self::DATE_FORMAT)),
            'type_form' => $this->getType($code),
            // slug используется только для старых форм и обратной совместимости
            'slug' => $attributes->get('slug', ''),
        ];
    }


    /**
     * @param $name
     * @param array $value
     * @return array
     */
    private function filter($name, $value = [])
    {
        return array_filter($this->data, static function ($form) use ($name, $value) {
            return in_array($form[$name], $value);
        });
    }


    /**
     * @param $code
     * @return string
     */
    protected function getType($code)
    {
        $regType = null;
        if (preg_match(
            '/[\"|\']form_type[\"|\']: [\"|\'](avia|hotel)[\"|\'],/',
            $code,
            $formType)
        ) {
            if (isset($formType[1])) {
                $regType = $formType[1];
            }
        }

        if (!empty($regType)) {
            switch ($regType) {
                case 'avia':
                    return SearchShortcodes::TYPE_AVIA;
                case 'hotel':
                    return SearchShortcodes::TYPE_HOTEL;

            }
        }

        return SearchShortcodes::TYPE_AVIA_HOTEL;
    }

    protected function optionPath()
    {
        return 'search_forms_search_forms_data';
    }

    private static function checkActive($forms)
    {
        return !empty($forms);
    }

    public function isActiveFlights()
    {
        return self::checkActive($this->getFlightsForms());
    }

    public function isActiveHotels()
    {
        return self::checkActive($this->getHotelsForms());
    }
}
