<?php
/**
 * Created by: Andrey Polyakov (andrey@polyakov.im)
 */

namespace Travelpayouts\modules\tables\components\flights\popularDestinationsAirlines;

use Travelpayouts\components\dictionary as Dictionaries;
use Travelpayouts\components\LanguageHelper;
use Travelpayouts\modules\tables\components\api\travelpayouts\v1\AirlineDirectionsApiModel;

class Api extends AirlineDirectionsApiModel
{
    public function afterRequest()
    {
        parent::afterRequest();

        $response = $this->response;
        if (is_array($response)) {
            $place = 0;
            $result = array_map(static function ($direction) use ($response, $place) {
                $popularity = $response[$direction];
                $place++;

                return [
                    'place' => $place,
                    'direction' => self::airportsToCities($direction),
                    'popularity' => $popularity,
                ];

            }, array_keys($response));
            $this->response = $result;
        }
    }

    private static function airportsToCities($directions)
    {
        if (!preg_match('/^[A-Z]{3}-[A-Z]{3}$/', $directions)) {
            return $directions;
        }

        $directionsArray = explode('-', $directions);
        $dictionary = Dictionaries\Airports::getInstance([
            'lang' => LanguageHelper::TABLE_DEFAULT
        ]);

        $cities = array_map(function ($code) use ($dictionary) {
            return $dictionary->getItem($code)->getCityCode();
        }, $directionsArray);

        return implode('-', $cities);
    }
}
